%*************************************************************************%
%                          U20 Friction Tool                              %
%                                                                         %
% This file is part of the U20 Friction Tool. The U20 Friction tool is    %
% free software. You can use, redistribute and modify it. If you publish  %
% results obtained with this tool (or any tool based on this code),       %
% please cite the following article:                                      %
%                                                                         %
% R.H.W. ten Thije, R. Akkerman, L. van der Meer, M. P. Ubbink,           %
% Tool-ply friction in thermoplastic composite forming,                   %
% International Journal of Material Forming, Volume 1, p. 953-956 (2008)  %
%                                                                         %
% This library is distributed in the hope that it will be useful, but     %
% WITHOUT ANY WARRANTY.                                                   %
%                                                                         %
% Copyright (C) 2009 Rene ten Thije.                                      %
% Developed at the University of Twente, the Netherlands.                 %
% Chair of Production Technology, www.pt.ctw.utwente.nl                   %
% info: r.tenthije@utwente.nl / r.akkerman@utwente.nl                     %
%                                                                         %
%*************************************************************************%

function cntr = create_contour(Type,par)

if strcmpi(Type,'ellips')
    
    % create an elliptic contour with cutt-offs if specified
    cntr.Type = 'ellips';

    % check for the parameters that must be present to create an ellips
    check_obl_par(par,'Rx','Ry','n');
    cntr.Rx = par.Rx;
    cntr.Ry = par.Ry;
    cntr.n  = par.n;

    % fields that get default values if not specified
    % set the defaults
    cntr.xmin = -par.Rx;
    cntr.xmax =  par.Rx;
    cntr.ymin =  0;
    cntr.ymax =  par.Ry;
    cntr.x0   =  0;
    cntr.y0   =  par.Ry;
    
    % reset them if they are specified
    cntr = check_def_par(cntr,par,'xmin','xmax','ymin','ymax','x0','y0');
    
    % create the contour
    x = linspace(cntr.xmin,cntr.xmax,cntr.n);
    y = cntr.ymax*ones(1,length(x));
    indx=(x>(cntr.x0-cntr.Rx))&(x<(cntr.x0+cntr.Rx));
    t=acos(x(indx)/cntr.Rx);
    y(indx)=cntr.y0-cntr.Ry*sin(t);
    y(y>cntr.ymax)=cntr.ymax;
    y(y<cntr.ymin)=cntr.ymin;

    % set the contour;
    cntr.x = x;
    cntr.y = y;
    cntr.dx= x(2)-x(1);
    
elseif strcmpi(Type,'polynom')
    
    % create an polynomial contour with cutt-offs if specified
    cntr.Type = 'polynom';

    % check for the parameters that must be present to create an ellips
    check_obl_par(par,'c','n','xmin','xmax');
    cntr.c     = par.c;
    cntr.order = length(par.c)-1;
    cntr.n     = par.n;
    cntr.xmin  = par.xmin;
    cntr.xmax  = par.xmax;

    % fields that get default values if not specified
    % set the defaults
    cntr.ymin =  0;
    cntr.ymax =  inf;
    cntr.x0   =  0;
    cntr.y0   =  0;
    
    % reset them if they are specified
    cntr = check_def_par(cntr,par,'ymin','ymax','x0','y0');
    
    % create the contour
    % the contour, using the polynomial equation of p
    x = linspace(cntr.xmin,cntr.xmax,cntr.n);
    y = cntr.c(end)*ones(1,length(x));
    for io=1:cntr.order
        y=y+cntr.c(end-io).*x.^io;
    end
    
    % cut off or translate if necessary
    y(y>cntr.ymax) = cntr.ymax;
    y(y<cntr.ymin) = cntr.ymin;
    x = x + cntr.x0;
    y = y + cntr.y0;
    
    % set the contour;
    cntr.x = x;
    cntr.y = y;
    cntr.dx= x(2)-x(1);    
else
    error('Unknown countour type.');
end
end

function check_obl_par(par,varargin)
for i = 1:nargin-1
    if ~isfield(par,varargin(i));
        errmsg=[char(varargin(i)),' must be specified in par by par.',char(varargin(i)),' = ..'];
        error(errmsg);
    end
end
end

function cntr = check_def_par(cntr,par,varargin)
for i = 1:nargin-2
    fld = char(varargin(i));
    if isfield(par,fld);
        val = par.(fld);
        cntr.(fld)=val;
    end
end
end