%*************************************************************************%
%                          U20 Friction Tool                              %
%                                                                         %
% This file is part of the U20 Friction Tool. The U20 Friction tool is    %
% free software. You can use, redistribute and modify it. If you publish  %
% results obtained with this tool (or any tool based on this code),       %
% please cite the following article:                                      %
%                                                                         %
% R.H.W. ten Thije, R. Akkerman, L. van der Meer, M. P. Ubbink,           %
% Tool-ply friction in thermoplastic composite forming,                   %
% International Journal of Material Forming, Volume 1, p. 953-956 (2008)  %
%                                                                         %
% This library is distributed in the hope that it will be useful, but     %
% WITHOUT ANY WARRANTY.                                                   %
%                                                                         %
% Copyright (C) 2009 Rene ten Thije.                                      %
% Developed at the University of Twente, the Netherlands.                 %
% Chair of Production Technology, www.pt.ctw.utwente.nl                   %
% info: r.tenthije@utwente.nl / r.akkerman@utwente.nl                     %
%                                                                         %
%*************************************************************************%

function [Geo] = create_geometry(g_type,side,warp_count,weft_count,spacing,thickness,npoints)

% warp count and weft count [1/mm]
% thickness of the fabric   [mm]
% the warp direction is the zero degree direction and pulling direction
% we distinguish top an bottom, as shown in the figure of the program
fill = 100-spacing;
B_warp     =  fill/100*1.0/warp_count;
B_weft     =  fill/100*1.0/weft_count;

Geo_Type = lower(g_type);
Side     = lower(side);

if strcmpi(Geo_Type,'plain') &&  strcmpi(Side,'top') % Plain weave, both sides

    c_type = 'ellips';
    
    % warp bundles
    c_par.Ry   =  thickness/4;
    c_par.Rx   =  B_weft/2;
    c_par.n    =  npoints; % number of points
    Contour_warp = create_contour(c_type,c_par);  % create the contour from the parameters

    % weft bundles
    c_par.Ry   =  thickness/4;
    c_par.Rx   =  B_weft/2;
    Contour_weft = create_contour(c_type,c_par);  % create the contour from the parameters

    % the geometry consists of one ore more contours, n defines the number of
    % times the contour should be taken into account
    Geo.nGeo       = 2;
    Geo.Contour{1} = Contour_warp;
    Geo.Width{1}   = B_warp;
    Geo.nCont{1}   = 2;
    Geo.Contour{2} = Contour_weft;
    Geo.Width{2}   = B_warp;
    Geo.nCont{2}   = 2;
    Geo.UCellArea  = 2*1/warp_count*2*1/weft_count;
    
elseif strcmpi(Geo_Type,'plain') &&  strcmpi(Side,'bottom') % Plain weave, both sides

    c_type = 'ellips';
    
    % warp bundles
    c_par.Ry   =  thickness/4;
    c_par.Rx   =  B_warp/2;
    c_par.n    =  npoints; % number of points
    Contour_warp = create_contour(c_type,c_par);  % create the contour from the parameters

    % weft bundles
    c_par.Ry   =  thickness/4;
    c_par.Rx   =  B_warp/2;
    Contour_weft = create_contour(c_type,c_par);  % create the contour from the parameters

    % the geometry consists of one ore more contours, n defines the number of
    % times the contour should be taken into account
    Geo.nGeo       = 2;
    Geo.Contour{1} = Contour_warp;
    Geo.Width{1}   = B_weft;
    Geo.nCont{1}   = 2;
    Geo.Contour{2} = Contour_weft;
    Geo.Width{2}   = B_weft;
    Geo.nCont{2}   = 2;
    Geo.UCellArea  = 2*1/warp_count*2*1/weft_count;
    
elseif strcmpi(Geo_Type,'22twill')  &&  strcmpi(Side,'top') % Twill weave

    c_type = 'ellips';
    
    % warp bundles
    c_par.Ry   =  thickness/4;
    c_par.Rx   =  B_weft;
    c_par.n    =  npoints; % number of points
    Contour_warp = create_contour(c_type,c_par);  % create the contour from the parameters

    % weft bundles
    c_par.Ry   =  thickness/4;
    c_par.Rx   =  B_weft/2;
    Contour_weft = create_contour(c_type,c_par);  % create the contour from the parameters

    % the geometry consists of one ore more contours, n defines the number of
    % times the contour should be taken into account
    Geo.nGeo       = 3;
    Geo.Contour{1} = Contour_warp;
    Geo.Width{1}   = B_warp;
    Geo.nCont{1}   = 4;
    for i=2:3
        Geo.Contour{i} = Contour_weft;
        Geo.Width{i}   = 2*B_warp;
        Geo.nCont{i}   = 2;
    end
    Geo.UCellArea  = 4*1/warp_count*4*1/weft_count;
    
elseif strcmpi(Geo_Type,'22twill')  &&  strcmpi(Side,'bottom') % Twill weave

    c_type = 'ellips';
    
    % warp bundles
    c_par.Ry   =  thickness/4;
    c_par.Rx   =  B_warp/2;
    c_par.n    =  npoints; % number of points
    Contour_warp = create_contour(c_type,c_par);  % create the contour from the parameters

    % weft bundles
    c_par.Ry   =  thickness/4;
    c_par.Rx   =  B_warp;
    Contour_weft = create_contour(c_type,c_par);  % create the contour from the parameters

    % the geometry consists of one ore more contours, n defines the number of
    % times the contour should be taken into account
    Geo.nGeo       = 3;
    for i=1:2
        Geo.Contour{i} = Contour_warp;
        Geo.Width{i}   = 2*B_weft;
        Geo.nCont{i}   = 2;
    end
    Geo.Contour{3} = Contour_weft;
    Geo.Width{3}   = B_weft;
    Geo.nCont{3}   = 4;
    Geo.UCellArea  = 4*1/warp_count*4*1/weft_count;

elseif strcmpi(Geo_Type,'31twill')  &&  strcmpi(Side,'top') % 31 Twill weave

    c_type = 'ellips';
    
    % warp bundles
    c_par.Ry   =  thickness/4;
    c_par.Rx   =  B_weft*3/2;
    c_par.n    =  npoints; % number of points
    Contour_warp = create_contour(c_type,c_par);  % create the contour from the parameters

    % weft bundles
    c_par.Ry   =  thickness/4;
    c_par.Rx   =  B_weft/2;
    Contour_weft = create_contour(c_type,c_par);  % create the contour from the parameters

    % the geometry consists of one ore more contours, n defines the number of
    % times the contour should be taken into account
    Geo.nGeo       = 2;
    Geo.Contour{1} = Contour_warp;
    Geo.Width{1}   = B_warp;
    Geo.nCont{1}   = 4;
    Geo.Contour{2} = Contour_weft;
    Geo.Width{2}   = B_warp;
    Geo.nCont{2}   = 4;
    Geo.UCellArea  = 4*1/warp_count*4*1/weft_count;
    
elseif strcmpi(Geo_Type,'31twill')  &&  strcmpi(Side,'bottom') % Twill weave

    c_type = 'ellips';
    
    % warp bundles
    c_par.Ry   =  thickness/4;
    c_par.Rx   =  B_warp/2;
    c_par.n    =  npoints; % number of points
    Contour_warp = create_contour(c_type,c_par);  % create the contour from the parameters

    % weft bundles
    c_par.Ry   =  thickness/4;
    c_par.Rx   =  B_warp/2;
    Contour_weft = create_contour(c_type,c_par);  % create the contour from the parameters

    % the geometry consists of one ore more contours, n defines the number of
    % times the contour should be taken into account
    Geo.nGeo       = 4;
    for i=1:3
        Geo.Contour{i} = Contour_warp;
        Geo.Width{i}   = 3*B_weft;
        Geo.nCont{i}   = 1;
    end
    Geo.Contour{4} = Contour_weft;
    Geo.Width{4}   = B_weft;
    Geo.nCont{4}   = 4;
    Geo.UCellArea  = 4*1/warp_count*4*1/weft_count;
    
elseif strcmpi(Geo_Type,'5hs') &&  strcmpi(Side,'top') % 5H Satin weave, side A

    c_type = 'ellips';
    
    % warp bundles
    c_par.Ry   =  thickness/4;
    c_par.Rx   =  4*B_weft/2;
    c_par.n    =  npoints; % number of points
    Contour_warp = create_contour(c_type,c_par);  % create the contour from the parameters

    % weft bundles
    c_par.Ry   =  thickness/4;
    c_par.Rx   =  B_weft/2;
    Contour_weft = create_contour(c_type,c_par);  % create the contour from the parameters

    % the geometry consists of one ore more contours, n defines the number of
    % times the contour should be taken into account
    Geo.nGeo       = 2;
    Geo.Contour{1} = Contour_warp;
    Geo.Width{1}   = B_warp;
    Geo.nCont{1}   = 5;
    Geo.Contour{2} = Contour_weft;
    Geo.Width{2}   = B_warp;
    Geo.nCont{2}   = 5;
    Geo.UCellArea  = 5*1/warp_count*5*1/weft_count;

elseif strcmpi(Geo_Type,'5hs') &&  strcmpi(Side,'bottom')  % 5H Satin weave
   
    c_type = 'ellips';
    
    % warp bundles
    c_par.Ry   =  thickness/4;
    c_par.Rx   =  B_warp/2;
    c_par.n    =  npoints; % number of points
    Contour_warp = create_contour(c_type,c_par);  % create the contour from the parameters

    % weft bundles
    c_par.Ry   =  thickness/4;
    c_par.Rx   =  B_warp/2;
    Contour_weft = create_contour(c_type,c_par);  % create the contour from the parameters

    % the geometry consists of one ore more contours, n defines the number of
    % times the contour should be taken into account
    Geo.nGeo       = 5;
    for i=1:4
        Geo.Contour{i} = Contour_warp;
        Geo.Width{i}   = 4*B_weft;
        Geo.nCont{i}   = 1;
    end
    Geo.Contour{5} = Contour_weft;
    Geo.Width{5}   = B_weft;
    Geo.nCont{5}   = 5;
    Geo.UCellArea  = 5*1/warp_count*5*1/weft_count;
    
elseif strcmpi(Geo_Type,'8hs') &&  strcmpi(Side,'top') % 8H Satin weave, side A
    % A side p14, Lieuwes report
    c_type = 'ellips';
    
    % warp bundles
    c_par.Ry   =  thickness/4;
    c_par.Rx   =  7*B_weft/2;
    c_par.n    =  npoints; % number of points
    Contour_warp = create_contour(c_type,c_par);  % create the contour from the parameters

    % weft bundles
    c_par.Ry   =  thickness/4;
    c_par.Rx   =  B_weft/2;
    Contour_weft = create_contour(c_type,c_par);  % create the contour from the parameters

    % the geometry consists of one ore more contours, n defines the number of
    % times the contour should be taken into account
    Geo.nGeo       = 2;
    Geo.Contour{1} = Contour_warp;
    Geo.Width{1}   = B_warp;
    Geo.nCont{1}   = 8;
    Geo.Contour{2} = Contour_weft;
    Geo.Width{2}   = B_warp;
    Geo.nCont{2}   = 8;
    Geo.UCellArea  = 8*1/warp_count*8*1/weft_count;

elseif strcmpi(Geo_Type,'8hs') &&  strcmpi(Side,'bottom')  % 8H Satin weave
    % BB side p14, Lieuwes report
    
    c_type = 'ellips';
    
    % warp bundles
    c_par.Ry   =  thickness/4;
    c_par.Rx   =  B_warp/2;
    c_par.n    =  npoints; % number of points
    Contour_warp = create_contour(c_type,c_par);  % create the contour from the parameters

    % weft bundles
    c_par.Ry   =  thickness/4;
    c_par.Rx   =  B_warp/2;
    Contour_weft = create_contour(c_type,c_par);  % create the contour from the parameters

    % the geometry consists of one ore more contours, n defines the number of
    % times the contour should be taken into account
    Geo.nGeo       = 8;
    for i=1:7
        Geo.Contour{i} = Contour_warp;
        Geo.Width{i}   = 7*B_weft;
        Geo.nCont{i}   = 1;
    end
    Geo.Contour{8} = Contour_weft;
    Geo.Width{8}   = B_weft;
    Geo.nCont{8}   = 8;
    Geo.UCellArea  = 8*1/warp_count*8*1/weft_count;
   
else
    error('unknown fabric type in create_geometry.')
end
