%*************************************************************************%
%                          U20 Friction Tool                              %
%                                                                         %
% This file is part of the U20 Friction Tool. The U20 Friction tool is    %
% free software. You can use, redistribute and modify it. If you publish  %
% results obtained with this tool (or any tool based on this code),       %
% please cite the following article:                                      %
%                                                                         %
% R.H.W. ten Thije, R. Akkerman, L. van der Meer, M. P. Ubbink,           %
% Tool-ply friction in thermoplastic composite forming,                   %
% International Journal of Material Forming, Volume 1, p. 953-956 (2008)  %
%                                                                         %
% This library is distributed in the hope that it will be useful, but     %
% WITHOUT ANY WARRANTY.                                                   %
%                                                                         %
% Copyright (C) 2009 Rene ten Thije.                                      %
% Developed at the University of Twente, the Netherlands.                 %
% Chair of Production Technology, www.pt.ctw.utwente.nl                   %
% info: r.tenthije@utwente.nl / r.akkerman@utwente.nl                     %
%                                                                         %
%*************************************************************************%

function [dydx] = centr_diff(y_or,dx,order)

% central difference for constant dx
% number of points must be at least 2*order

if nargin ~=3
    order = 1;
end

if length(y_or)<2*order
    error('length of y must be at least 2*order and at least 3 for centr_diff');
end

% make it a horizontal vector
[a,b]=size(y_or);
if a > b
    y_or = y_or';
end
y = y_or;

for i=1:order
    % loop to find the derivatives of the inner points
    diff_y    = diff(y);
    dy        = diff_y(1:end-1)+diff_y(2:end);
    dydx      = 0.5/dx * dy;
    y         = dydx;
end

% make a fit to find the first and last n derivatives
n_poly    = order + 1; % we need an order + 1 polynomial
n_points  = order + 2; % we need order + 2 points
x_poly    = linspace(0,n_poly*dx,n_points)';
M = ones(n_points,n_points);
for i = 1:n_poly
    M(:,i) = x_poly.^(n_points-i);
end

% the derivatives at the start
b = y_or(1:n_points)';
coeff = M\b;
dydx_left = factorial(n_poly)*coeff(1)*x_poly(1:order)'+factorial(n_poly-1)*coeff(2);

% the derivatives at the end
b = y_or(end-n_points+1:end)';
coeff = M\b;
dydx_right = factorial(n_poly)*coeff(1)*x_poly(3:end)'+factorial(n_poly-1)*coeff(2);

% the derivative
dydx = [dydx_left,dydx,dydx_right];

%%
% alternative recursive way with a 2nd order polynomial fit on the borders
% in each loop

% dydx = zeros(1,length(y_or));
% y=y_or;
% for i=1:order
%     diff_y    = diff(y);
%     dy        = diff_y(1:end-1)+diff_y(2:end);
%     dydx(2:end-1)  = 0.5/dx * dy;
%     dydx(1)     = diff_y(1)/dx;
%     dydx(end)   = diff_y(end)/dx;
%     
%     % based on 2nd order polynom
%     M = [   0        0   1;
%           dx^2      dx   1;
%          (2*dx)^2  2*dx  1];
%     % first point 
%     b = y(1:3)';
%     coeff = M\b;
%     dydx(1) = coeff(2);
%     % last point 
%     b = y(end-2:end)';
%     coeff = M\b;
%     dydx(end) = 2*coeff(1)*2*dx+coeff(2);
%     
%     y = dydx;
% end